package com.xinelu.manage.service.orderevaluateinfo;


import com.xinelu.manage.domain.orderevaluateinfo.OrderEvaluateInfo;

import java.util.List;


/**
 * 预约服务订单和商品订单评价信息Service接口
 *
 * @author xinyilu
 * @date 2022-11-17
 */
public interface IOrderEvaluateInfoService {

    /**
     * 查询预约服务订单和商品订单评价信息
     *
     * @param id 预约服务订单和商品订单评价信息主键
     * @return 预约服务订单和商品订单评价信息
     */
    OrderEvaluateInfo selectOrderEvaluateInfoById(Long id);

    /**
     * 查询预约服务订单和商品订单评价信息列表
     *
     * @param orderEvaluateInfo 预约服务订单和商品订单评价信息
     * @return 预约服务订单和商品订单评价信息集合
     */
    List<OrderEvaluateInfo> selectOrderEvaluateInfoList(OrderEvaluateInfo orderEvaluateInfo);

    /**
     * 新增预约服务订单和商品订单评价信息
     *
     * @param orderEvaluateInfo 预约服务订单和商品订单评价信息
     * @return 结果
     */
    int insertOrderEvaluateInfo(OrderEvaluateInfo orderEvaluateInfo);

    /**
     * 修改预约服务订单和商品订单评价信息
     *
     * @param orderEvaluateInfo 预约服务订单和商品订单评价信息
     * @return 结果
     */
    int updateOrderEvaluateInfo(OrderEvaluateInfo orderEvaluateInfo);

    /**
     * 批量删除预约服务订单和商品订单评价信息
     *
     * @param ids 需要删除的预约服务订单和商品订单评价信息主键集合
     * @return 结果
     */
    int deleteOrderEvaluateInfoByIds(Long[] ids);

    /**
     * @Author mengkuiliang
     * @Description 根据服务编号查询服务评价列表
     * @Date 2023-10-17 017 11:35
     * @Param [orderEvaluateInfo]
     * @return java.util.List<com.xinelu.manage.domain.orderevaluateinfo.OrderEvaluateInfo>
     **/
    List<OrderEvaluateInfo> selectOrderEvaluateByServiceNos(List<String> orderNoList, String orderSource);

}
