package com.xinelu.manage.controller.orderevaluateinfo;

import com.xinelu.common.annotation.Log;
import com.xinelu.common.core.controller.BaseController;
import com.xinelu.common.core.domain.AjaxResult;
import com.xinelu.common.core.page.TableDataInfo;
import com.xinelu.common.enums.BusinessType;
import com.xinelu.common.utils.poi.ExcelUtil;
import com.xinelu.manage.domain.orderevaluateinfo.OrderEvaluateInfo;
import com.xinelu.manage.service.orderevaluateinfo.IOrderEvaluateInfoService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 预约服务订单和商品订单评价信息Controller
 *
 * @author xinyilu
 * @date 2022-11-17
 */
@RestController
@RequestMapping("/system/orderEvaluateInfo")
public class OrderEvaluateInfoController extends BaseController {
    @Resource
    private IOrderEvaluateInfoService orderEvaluateInfoService;

    /**
     * 查询预约服务订单和商品订单评价信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:orderEvaluateInfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(OrderEvaluateInfo orderEvaluateInfo) {
        startPage();
        List<OrderEvaluateInfo> list = orderEvaluateInfoService.selectOrderEvaluateInfoList(orderEvaluateInfo);
        return getDataTable(list);
    }

    /**
     * 导出预约服务订单和商品订单评价信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:orderEvaluateInfo:export')")
    @Log(title = "预约服务订单和商品订单评价信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, OrderEvaluateInfo orderEvaluateInfo) {
        List<OrderEvaluateInfo> list = orderEvaluateInfoService.selectOrderEvaluateInfoList(orderEvaluateInfo);
        ExcelUtil<OrderEvaluateInfo> util = new ExcelUtil<>(OrderEvaluateInfo.class);
        util.exportExcel(response, list, "预约服务订单和商品订单评价信息数据");
    }

    /**
     * 获取预约服务订单和商品订单评价信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:orderEvaluateInfo:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return AjaxResult.success(orderEvaluateInfoService.selectOrderEvaluateInfoById(id));
    }

    /**
     * 新增预约服务订单和商品订单评价信息
     */
    //@PreAuthorize("@ss.hasPermi('system:orderEvaluateInfo:add')")
    @Log(title = "预约服务订单和商品订单评价信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    public AjaxResult add(@RequestBody OrderEvaluateInfo orderEvaluateInfo) {
        return toAjax(orderEvaluateInfoService.insertOrderEvaluateInfo(orderEvaluateInfo));
    }

    /**
     * 修改预约服务订单和商品订单评价信息
     */
    @PreAuthorize("@ss.hasPermi('system:orderEvaluateInfo:edit')")
    @Log(title = "预约服务订单和商品订单评价信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody OrderEvaluateInfo orderEvaluateInfo) {
        return toAjax(orderEvaluateInfoService.updateOrderEvaluateInfo(orderEvaluateInfo));
    }

    /**
     * 删除预约服务订单和商品订单评价信息
     */
    @PreAuthorize("@ss.hasPermi('system:orderEvaluateInfo:remove')")
    @Log(title = "预约服务订单和商品订单评价信息", businessType = BusinessType.DELETE)
    @PostMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(orderEvaluateInfoService.deleteOrderEvaluateInfoByIds(ids));
    }
}
